@@ -173,7 +173,7 @@ class DB:
 
         def build_expression():  # apply diff
             set_actions = []
-            delete_actions = []
+            remove_actions = []
             names = {}
             values = {}
 
@@ -194,7 +194,7 @@ class DB:
                     for old_sub_name in old_item.get(name, {}):
                         if old_sub_name not in value:
                             hashed_old_sub_name = self._hash_name(old_sub_name)
-                            delete_actions.append(f"#{hashed_name}.#{hashed_old_sub_name}")
+                            remove_actions.append(f"#{hashed_name}.#{hashed_old_sub_name}")
                             names[f"#{hashed_name}"] = name
                             names[f"#{hashed_old_sub_name}"] = old_sub_name
 
@@ -206,14 +206,14 @@ class DB:
             for old_name in old_item:
                 if old_name not in item:
                     hashed_old_name = self._hash_name(old_name)
-                    delete_actions.append(f"#{hashed_old_name}")
+                    remove_actions.append(f"#{hashed_old_name}")
                     names[f"#{hashed_old_name}"] = old_name
 
             clauses = []
             if set_actions:
                 clauses.append("SET " + ", ".join(set_actions))
-            if delete_actions:
-                clauses.append("DELETE " + ", ".join(delete_actions))
+            if remove_actions:
+                clauses.append("REMOVE " + ", ".join(remove_actions))
             return " ".join(clauses), names, values
 
         expression, expression_names, expression_values = build_expression()
